/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 *
 *       Filename:  alertmodel.cpp
 *
 *    Description:  Alerts data model 
 *
 *        Created:  2007-08-10 20:21:52 CEST
 *
 *	Copyright (C) 2007 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 *
 * =====================================================================================
 */

#include "alertmodel.h"
#include <QtAlgorithms>

AlertModel::AlertModel(alertManager *man) : KismetDataModel<AlertRootItem,AlertItem>()
{
        colCount        = 0;
        connect(man,SIGNAL(data(alertInfo)),this,SLOT(alInfo(alertInfo)));
        connect(man,SIGNAL(capabilitiesChanged()),this,SLOT(updateColumns()));
        manager = man;
}

QVariant AlertModel::data(const QModelIndex &index, int role) const
{
	if(!index.isValid())
		return QVariant();
	if(role != Qt::DisplayRole)
		return QVariant();

	AlertItem *item	= static_cast<AlertItem*>(index.internalPointer());
        return item->data(columnToOption[index.column()]);
}

QVariant AlertModel::headerData(int section, Qt::Orientation orientation,int role) const
{
        if(orientation == Qt::Horizontal && role == Qt::DisplayRole)
                return alertManager::optionName(columnToOption[section]);
	return QVariant();
}

QModelIndex AlertModel::index(int row, int column, const QModelIndex &parent) const
{
	if(!hasIndex(row,column,parent))
		return QModelIndex();
	
	
	AlertItem *it	= rootItem->items[row];
	if(it)
		return createIndex(row,column,it);
	else
		return QModelIndex();
}

QModelIndex AlertModel::parent(const QModelIndex &index) const
{
	if(index.isValid())
		return QModelIndex();
	
	return QModelIndex();
}

int AlertModel::columnCount(const QModelIndex&) const
{
        return colCount;// return socket->alert.getNames()->size();
}

void AlertModel::alInfo(alertInfo info)
{
        AlertItem *item = findItem(info);
        int c	= rootItem->items.size();
	
        if(item)
	{
		//Update existing item
                *item |= info;
                int r 	= item->row();
                emit dataChanged(createIndex(r,0,item),createIndex(r,colCount,item));
        }
        else
	{
		beginInsertRows(QModelIndex(),c,c);
	
                item	= new AlertItem(info,rootItem);
		rootItem->items.append(item);
	
		endInsertRows();
        }
}

AlertItem* AlertModel::findItem(const alertInfo &it)
{
        foreach(AlertItem* t, rootItem->items)
                if(t->sec == it.sec && t->usec == it.usec)
                        return t;
        return 0;
}


//AlertItem implementation

AlertItem::AlertItem(alertInfo &data, AlertRootItem *parent) : alertInfo(data)
{
	root	= parent;
#if QT_VERSION < 0x040200
	QDateTime time;
	time.setTime_t(data->props[0].toInt());
#else
//	time	= QDateTime::fromTime_t(data->props[0].toInt());
#endif
}

void AlertModel::updateColumns()
{
        beginRemoveColumns(QModelIndex(),0,colCount-1);
        colCount        = 0;
        endRemoveColumns();

        columnToOption.clear();
        int i = 0;
        foreach(alertOption opt,manager->availableOptions())
               columnToOption[i++]     = opt;

        beginInsertColumns(QModelIndex(),0,i-1);
        colCount        = i;
        endInsertColumns();
}

const QHash<int, alertOption>& AlertModel::columnOptions()
{
        return columnToOption;
}

AlertItem::~AlertItem()
{
	//TODO: clean clients
}

QVariant AlertItem::data(alertOption opt)
{
        return this->*optionToMember[opt];
}

AlertRootItem* AlertItem::parent()
{
	return root;
}

int AlertItem::row()
{
	return root->items.indexOf(this);
}
