/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 * 
 *       Filename:  alertmodel.h
 * 
 *    Description:  Alerts data model
 * 
 *        Created:  2007-08-10 20:18:44 CEST
 * 
 *	Copyright (C) 2007 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 * 
 * =====================================================================================
 */

#ifndef  ALERTMODEL_INC
#define  ALERTMODEL_INC

#include <QAbstractItemModel>
#include <QVariant>
#include <QDateTime>
#include <QPair>

#include "kisock.h"
#include "kismodel.h"
#include "alertinfo.h"

struct AlertRootItem;

class AlertItem : public alertInfo
{
public:
        AlertItem(alertInfo &data, AlertRootItem *parent);
	~AlertItem();

	int row();
        QVariant data(alertOption opt);

	AlertRootItem *parent();

private:
	AlertRootItem *root;
};

struct AlertRootItem
{
	public:
		QList<AlertItem*> items;
};

class AlertModel : public KismetDataModel<AlertRootItem, AlertItem>
{
	Q_OBJECT
public:
                AlertModel(alertManager *man);

		QVariant data(const QModelIndex &index, int role) const;
		QVariant headerData(int section, Qt::Orientation orientation,int role = Qt::DisplayRole) const;

		QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const;
		QModelIndex parent(const QModelIndex &index) const;
		int columnCount(const QModelIndex &parent = QModelIndex()) const;

                const QHash<int,alertOption>& columnOptions();

public slots:
                void alInfo(alertInfo info);
private:
                QHash<int,alertOption> columnToOption;
                int colCount;
                alertManager *manager;

                AlertItem *findItem(const alertInfo &it);
private slots:
                void updateColumns();
};
#endif   /* ----- #ifndef ALERTMODEL_INC  ----- */

