/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 *
 *       Filename:  alertview.cpp
 *
 *    Description:  Alerts window 
 *
 *        Created:  2007-07-05 16:14:10 CEST
 *
 *	Copyright (C) 2007 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 *
 * =====================================================================================
 */
#include "alertview.h"


#include <QHeaderView>
#include <QApplication>
#include <QTime>

#include <QToolBar>
#include <QSettings>

QKismetAlertWnd::QKismetAlertWnd(QKismetSocket *sock)
{
	tree	= new QKismetAlertView(sock);
	toolbar	= new QKismetViewToolBar(tree);

	tree->popupMenu->addSeparator();
	tree->popupMenu->addAction(toolbar->toggleViewAction());
	
	setCentralWidget(tree);
	addToolBar(toolbar);
}
QKismetAlertWnd::~QKismetAlertWnd()
{

	delete tree;
	delete toolbar;
}

QKismetAlertDock::QKismetAlertDock(QKismetSocket *sock)
{
	hide();
	
	wnd	= new QKismetAlertWnd(sock);

	QAction *a = toggleViewAction();
	a->setIcon(QIcon(":/img/emblem-important.png"));
	a->setStatusTip("Toggle alerts window");
	setWindowTitle("Alerts");

	setWidget(wnd);
}
QKismetAlertDock::~QKismetAlertDock()
{
	delete wnd;
}

QKismetAlertView::QKismetAlertView(QKismetSocket *sock) : QKismetTreeView(new AlertModel((man = alertManager::manager(sock))))
{
        man->setOption(AlertOptions::Time);
        connect(man,SIGNAL(activeChanged()),this,SLOT(updateColumnVisibility()));
        connect(man,SIGNAL(capabilitiesChanged()),this,SLOT(updateColumnVisibility()));


        QSettings set("qkismet","qkismet");
        set.beginGroup("AlertViewSettings");
        QList<QVariant> options;


        options = set.value("Options",QList<QVariant>() << AlertOptions::Time << AlertOptions::Text).toList();
        foreach(QVariant v,options)
                man->setOption(v.toInt());

	setRootIsDecorated(false);
	createMenus();
        updateColumnVisibility();
}

QKismetAlertView::~QKismetAlertView()
{
        SaveSettings();
}

void QKismetAlertView::createMenus()
{
        headMenu	= new HeadMenu(man,this);

	QHeaderView *head = header();

	head->setContextMenuPolicy(Qt::CustomContextMenu);
        connect(head,SIGNAL(customContextMenuRequested(const QPoint&)),headMenu,SLOT(show(const QPoint&)));

}

void QKismetAlertView::SaveSettings()
{
        QSettings set("qkismet","qkismet");
        set.beginGroup("AlertViewSettings");

        QList<QVariant> opts;

        foreach(alertOption o,man->enabledOptions())
                opts << (int)o;

        set.setValue("Options",opts);
}

void QKismetAlertView::updateColumnVisibility()
{
        AlertModel *mod       = (AlertModel*)dataModel();

        QSet<alertOption> enabled     = man->enabledOptions();
        QSet<protocolOption> avail      = man->availableOptions();

        foreach(protocolOption opt,avail)
        {
                int id  = mod->columnOptions().key(opt,0);

                if(enabled.contains(opt))
                        showColumn(id);
                else
                        hideColumn(id);
        }
}
