/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 *
 *       Filename:  datamanager.h
 *
 *    Description:  Base class for *Managers
 *
 *        Created:  2009-09-10 12:19:51 CEST
 *
 *	Copyright (C) 2009 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 *
 * =====================================================================================
 */

#ifndef DATAMANAGER_H
#define DATAMANAGER_H

#include <QSet>
#include "kismetresponse.h"


//This class is some kind of wrapper for int and different enum types.
//Some classes (headMenu) need to deal with different types of '*option',
//instead of using templates (making code unnecesary complicated in some places),
//every *Option type derives from this (since it's impossible to derive from enum type)

class protocolOption
{
        protected:
                int opt;
        public:
                protocolOption(int a){opt = a;}
                protocolOption(){opt = -1;}
                operator int() const {return opt;}
                bool operator == (const protocolOption &en) const {return en.opt == opt;}  
};

class dataManager : public QObject
{
        Q_OBJECT
public:
        //Parse data for specified protocol
        virtual void parseData(const QString &protocol, kismetResponse &response) = 0;

        //Options that can be toggled
        virtual const QSet<protocolOption>& availableOptions(){return available;}

        //Screen name for specified option
        virtual QString optionName(protocolOption){return "";}

        //Is specified option enabled ?
        virtual bool isOptionEnabled(protocolOption){return false;}
signals:
        //Emitted when capabilites changed
        void capabilitiesChanged();

        //Emitted when set of selected options changed
        void activeChanged();
public slots:

        //Toggle specified option
        virtual void setOption(protocolOption,bool){}

protected:

        //available   - list of options supported by server
        QSet<protocolOption> available;
};

#endif // DATAMANAGER_H
