/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 *
 *       Filename:  formattingutils.cpp
 *
 *    Description:  Data formatting utilities
 *
 *        Created:  2007-07-05 16:14:10 CEST
 *
 *	Copyright (C) 2007 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 *
 * =====================================================================================
 */

#include <QHash>
#include <QStringList>
#include "formattingutils.h"


enum networkEncryption
{
        None    = 0,
        Unknown = 1,
        Wep     = (1 << 1),
        Layer3  = (1 << 2),
        Wep40   = (1 << 3),
        Wep104  = (1 << 4),
        Tkip    = (1 << 5),
        Wpa     = (1 << 6),
        Psk     = (1 << 7),
        Aesocb  = (1 << 8),
        Aesccm  = (1 << 9),
        Leap    = (1 << 10),
        Ttls    = (1 << 11),
        Tls     = (1 << 12),
        Peap    = (1 << 13),
        Isakmp  = (1 << 14),
        Pptp    = (1 << 15),
        Fortress        = (1 << 16),
        Keyguard        = (1 << 17)
};

QHash<networkEncryption,QString> encryptionName;

QString formattingUtils::networkEncryption(int i)
{
        if(!encryptionName.size())
                fillArrays();


        QStringList enc;
        if(i == None)
                return "None";
        else if(i == Wep)
                enc << "WEP";

        foreach(::networkEncryption en, encryptionName.keys())
                if(i & en)
                        enc << encryptionName[en];
        return enc.join(" ");
}

QString formattingUtils::dataSize(int i)
{
        if(i < 1024)
                return QString::number(i) + " B";
        else if(i < 1024*1024)
                return QString::number(i/1024) + " KB";
        else if(i < 1024*1024*1024)
                return QString::number(i/(1024*1024)) + " MB";
        else /*if(i < 1024*1024*1024*1024)*/
                return QString::number(i/(1024*1024*1024)) + " GB";
}

QString formattingUtils::networkType(int value)
{
        switch(value)
        {
                case 0:	return "Access point";
                        break;
                case 1:	return "Ad-Hoc";
                        break;
                case 2:	return "Probe";
                        break;
                case 3: return "Turbocell";
                        break;
                case 4: return "Data";
                        break;
                default:
                        return "?";
        }
}

QString formattingUtils::frequency(const QString & value, int packets)
{
        QStringList out;
        QStringList l   = value.split('*');

        foreach(QString str,l)
        {
                QStringList list        = str.split(':');
                if(list.size() > 1)
                {
                        QString s       = list[0] + " - " + list[1];
                        if(packets > -1)
                        {
                                s       += ", ";
                                s       += QString::number(list[1].toFloat()/packets*100.0);
                                s       += "%";
                        }
                        out << s;
                }
        }
        return out.join(",");
}

void formattingUtils::fillArrays()
{
        //encryptionName[None]            = "None";
        encryptionName[Unknown]         = "Unknown";
        //encryptionName[Wep]             = "WEP";
        encryptionName[Layer3]          = "Layer 3";
        encryptionName[Wep40]           = "WEP 40";
        encryptionName[Wep104]          = "WEP 104";
        encryptionName[Tkip]            = "TKIP";
        encryptionName[Wpa]             = "WPA";
        encryptionName[Psk]             = "PSK";
        encryptionName[Aesocb]          = "AES/OCB";
        encryptionName[Aesccm]          = "AES/CCM";
        encryptionName[Leap]            = "LEAP";
        encryptionName[Ttls]            = "TTLS";
        encryptionName[Tls]             = "TLS";
        encryptionName[Peap]            = "PEAP";
        encryptionName[Isakmp]          = "ISAKMP";
        encryptionName[Pptp]            = "PPTP";
        encryptionName[Fortress]        = "Fortress";
        encryptionName[Keyguard]        = "Keyguard";
}
