/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 *
 *       Filename:  headmenu.cpp
 *
 *    Description:  Menu for list headers
 *
 *        Created:  2007-09-12 15:35:35 CEST
 *
 *	Copyright (C) 2007 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 *
 * =====================================================================================
 */

#include "headmenu.h"


QKismetAction::QKismetAction(protocolOption option, const QString& text,QObject *parent) : QAction(text,parent)
{
        opt  = option;
	setCheckable(true);
        connect(this,SIGNAL(triggered()),this,SLOT(trig()));
}

void QKismetAction::trig()
{
        emit triggered(opt,isChecked());
}

protocolOption QKismetAction::option()
{
        return opt;
}

HeadMenu::HeadMenu(dataManager *m, QKismetTreeView* /**view*/)
{
        man     = m;
        connect(m,SIGNAL(capabilitiesChanged()),this,SLOT(updateData()));
        connect(m,SIGNAL(activeChanged()),this,SLOT(updateSelected()));
        updateData();
        updateSelected();
}

void HeadMenu::show(const QPoint& pos)
{
        exec(((QWidget*)sender())->mapToGlobal(pos));
}

void HeadMenu::updateData()
{
        foreach(QAction *a, acts)
                removeAction(a);

        acts.clear();

        foreach(protocolOption op, man->availableOptions())
        {
                QKismetAction *a      = new QKismetAction(op,man->optionName(op),this);
                connect(a,SIGNAL(triggered(protocolOption,bool)),man,SLOT(setOption(protocolOption,bool)));
                addAction(a);
                acts.append(a);
        }
        updateSelected();
}

void HeadMenu::updateSelected()
{
        foreach(QKismetAction *a, acts)
                a->setChecked(man->isOptionEnabled(a->option()));
}
