/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 *
 *       Filename:  infoinfo.cpp
 *
 *    Description:  Contains information from INFO protcol
 *
 *        Created:  2009-09-20 12:30:13 CEST
 *
 *	Copyright (C) 2009 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 *
 * =====================================================================================
 */

#ifndef INFOINFO_H
#define INFOINFO_H

#include "protocolmanager.h"

class QKismetSocket;

namespace InfoOptions
{

enum infoOptionEnum{Networks,Packets,Crypt,Noise,Dropped,Rate,Filtered,Clients,
                    Llcpackets,Datapackets,Numsources,Numerrorsources,Weak,Signal,INVALID};
}

class infoOption : public protocolOption
{
public:
        infoOption(const protocolOption &en){opt = (int)en;}
        infoOption(InfoOptions::infoOptionEnum en){opt = (int)en;}
        infoOption(){opt = -1;}

        operator int() const {return opt;}
        operator InfoOptions::infoOptionEnum() const {return (InfoOptions::infoOptionEnum)opt;}
        operator protocolOption() const {return protocolOption(opt);}

        infoOption & operator =(const InfoOptions::infoOptionEnum &en) {opt = (int)en;return *this;}
        bool operator == (const InfoOptions::infoOptionEnum &en) const {return ((int)en) == opt;}
        bool operator == (const infoOption &en) const {return en.opt == opt;}

};

uint qHash(const infoOption& opt);
uint qHash(const protocolOption& opt);

class infoManager;

class infoInfo
{
public:
        //Constructs clientInfo object from Kismet response,
        //fields (and their orders) specified by "options"
        infoInfo(kismetResponse &response, QSet<infoOption> &options);

        QString networks,packets,crypt,noise,dropped,rate,filtered,clients,llcpackets,
                datapackets,numsources,numerrorsources,weak,signal;
protected:
        static QHash<infoOption,QString infoInfo::*> optionToMember;
private:
        static void fillArray();
};

class infoManager : public dataManager
{
        Q_OBJECT
public:
        static infoManager* manager(QKismetSocket *socket);

        //Called when "response" received for "protocol"
        void parseData(const QString &protocol, kismetResponse &response);

        void setOption(protocolOption opt, bool enable = true);

signals:
        //Emitted when there's some info
        void data(infoInfo info);

private:
        infoManager(QKismetSocket *socket);

        //Called when user changed settings in order to send commands to kismet server
        void update();

        QKismetSocket *sock;

        //Currently enabled options
        QSet<infoOption> options;

        //Conversion between infoOption and Kismet protocol field
        static QHash<infoOption,QString> optionToInfo;

        void initArrays();
private slots:
        void socketReady();

        //Called when info about supported protocol fields received
        void capabilitiesChanged(const QString& protocol);
};

#endif // INFOINFO_H
