/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 *
 *       Filename:  infoview.cpp
 *
 *    Description:  Info window 
 *
 *        Created:  2007-08-22 13:50:34 CEST
 *
 *	Copyright (C) 2007 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 *
 * =====================================================================================
 */

#include "infoview.h"

QKismetInfoDock::QKismetInfoDock(QKismetSocket *sock) : infownd(sock)
{
	hide();
	
	QAction *a = toggleViewAction();
        a->setIcon(QIcon(":/img/info.png"));
	a->setStatusTip("Toggle Info window");
	setWindowTitle("Info");

	setWidget(&infownd);
}



QKismetInfoDock::~QKismetInfoDock()
{
}


QKismetInfoWnd::QKismetInfoWnd(QKismetSocket *sock) : main(QBoxLayout::TopToBottom)
{
	socket		= sock;
	vertical	= true;

	setLayout(&main);
	main.addLayout(&card);
	main.addStretch(0);

	card.addWidget(&networks);
	card.addWidget(&packets);
	card.addWidget(&crypt);
	card.addWidget(&noise);
	card.addWidget(&dropped);
	card.addWidget(&rate);
	card.addWidget(&signal);
	
        manager = infoManager::manager(sock);
        manager->setOption(InfoOptions::Networks);
        manager->setOption(InfoOptions::Dropped);
        manager->setOption(InfoOptions::Rate);
        manager->setOption(InfoOptions::Packets);
        manager->setOption(InfoOptions::Crypt);
        manager->setOption(InfoOptions::Noise);

        connect(manager,SIGNAL(data(infoInfo)),this,SLOT(update(infoInfo)));
}

QKismetInfoWnd::~QKismetInfoWnd()
{

}

void QKismetInfoWnd::update(infoInfo info)
{
        networks.setText("Networks: \t"+info.networks);
        packets.setText("Packets: \t"+info.packets);
        crypt.setText("Crypted: \t"+info.crypt);
        noise.setText("Noise: \t"+info.noise);
        dropped.setText("Dropped: \t"+info.dropped);
        rate.setText("Packet rate: \t"+info.rate + "/s");
}
