/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 *
 *       Filename:  kisfilter.cpp
 *
 *    Description:  Filter model 
 *
 *        Created:  2007-08-13 16:16:21 CEST
 *
 *	Copyright (C) 2007 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 *
 * =====================================================================================
 */
#include "kisfilter.h"
#include <QDebug>


KismetSortFilterProxy::KismetSortFilterProxy()
{
	binv	= false;
	mode	= Contains;
	bcas	= false;
	setFilterCaseSensitivity(Qt::CaseInsensitive);
}

void KismetSortFilterProxy::setInvert(bool inv)
{
	if(binv != inv)
	{
		binv	= inv;
#if QT_VERSION >= 0x040300
invalidateFilter();
#elif QT_VERSION < 0x040200
clear();
#elif QT_VERSION < 0x040300
filterChanged();
#endif
	}
}

void KismetSortFilterProxy::setMode(filterMode mod)
{
	if(mode	!= mod)
	{	
		mode	= mod;
#if QT_VERSION >= 0x040300
invalidateFilter();
#elif QT_VERSION < 0x040200
clear();
#elif QT_VERSION < 0x040300
filterChanged();
#endif
	}
}

void KismetSortFilterProxy::setCaseSensitive(bool cas)
{
	if(bcas != cas)
	{
		bcas	= cas;
		setFilterCaseSensitivity((bcas) ? Qt::CaseSensitive : Qt::CaseInsensitive);
#if QT_VERSION >= 0x040300
invalidateFilter();
#elif QT_VERSION < 0x040200
clear();
#elif QT_VERSION < 0x040300
filterChanged();
#endif
	}
}
void KismetSortFilterProxy::setFilterString(const QString& str)
{
	if(str != strexp)
	{
		strexp	= str;
		if(mode == RegExp)
			setFilterRegExp(strexp);
		else
		{
#if QT_VERSION >= 0x040300
invalidateFilter();
#elif QT_VERSION < 0x040200
clear();
#elif QT_VERSION < 0x040300
filterChanged();
#endif
		}
	}
}

bool KismetSortFilterProxy::checkStarts(const QString &s)
{
	return s.startsWith(strexp,filterCaseSensitivity());
}
bool KismetSortFilterProxy::checkEnds(const QString &s)
{
	return s.endsWith(strexp,filterCaseSensitivity());
}
bool KismetSortFilterProxy::checkEq(const QString &s)
{
	#if QT_VERSION >= 0x040200
	return (s.compare(strexp,filterCaseSensitivity()) == 0);
	#else
	return s == strexp;
	#endif
}
bool KismetSortFilterProxy::checkRegExp(const QString &s)
{
	return s.contains(filterRegExp());
}
bool KismetSortFilterProxy::checkContains(const QString &s)
{
	return s.contains(strexp,filterCaseSensitivity ());
}
bool KismetSortFilterProxy::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const
{
	if(strexp == "")
		return true;
	QModelIndex index;
	int j		= sourceModel()->columnCount();
	bool acc	= false;

        bool (KismetSortFilterProxy::*func)(const QString&);
	
	switch(mode)
	{
		case Contains:
			func	= &KismetSortFilterProxy::checkContains;
			break;
		case Starts:
			func	= &KismetSortFilterProxy::checkStarts;
			break;
		case Ends:
			func	= &KismetSortFilterProxy::checkEnds;
			break;
		case Equals:
			func	= &KismetSortFilterProxy::checkEq;
			break;
		default:
			func	= &KismetSortFilterProxy::checkRegExp;
	}


	for(int i = 0; i < j;i++)
        {
		index	= sourceModel()->index(sourceRow,i,sourceParent);
		if((const_cast<KismetSortFilterProxy*>(this)->*func)(sourceModel()->data(index).toString()))
		{
			acc	= true;
			break;
		}
	}

	
	return (binv) ? !acc : acc;
}
