/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 *
 *       Filename:  kismetinfo.cpp
 *
 *    Description:  Info about kismet server
 *
 *        Created:  2009-07-04 13:20:57 CEST
 *
 *	Copyright (C) 2007 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 *
 * =====================================================================================
 */

#include "kismetinfo.h"

#include <QVariant>
#include <QDebug>

kismetInfo::kismetInfo(kismetResponse &res)
{
        ver	= res.read().toString();
        stime  	= res.read().toInt();
        nam	= res.read().toString();

        //Now we need to detect protocol version (Newcore/Old).
        //In old protocol here comes timestamp,
        //in newcore - list of dump file types separated by comma.
        //Additionaly, in newcore value is enclosed in \001 bytes.
        bld    = res.read(&nc).toString();
        if(nc)
        {
                qDebug() << "Newcore";
                suid  	= res.read().toInt();
                smax     = res.read().toInt();
        }
        else
        {
                qDebug() << "Old";
                chop    = res.read().toBool();
                nver    = res.read().toString();
        }
}

QString kismetInfo::version()
{
        return ver;
}

QString kismetInfo::timestamp()
{
        return bld;
}

QString kismetInfo::name()
{
        return nam;
}

QString kismetInfo::newVersion()
{
        return nver;
}

int kismetInfo::time()
{
        return stime;
}

bool kismetInfo::channelHop()
{
        return chop;
}

bool kismetInfo::newcore()
{
        return nc;
}

int kismetInfo::uid()
{
        return suid;
}

int kismetInfo::max()
{
        return smax;
}

QString kismetInfo::dumpFiles()
{
        return bld;
}
