/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 *
 *       Filename:  kismetresponse.cpp
 *
 *    Description:  Parsing Kismet data
 *
 *        Created:  2009-07-04 13:40:57 CEST
 *
 *	Copyright (C) 2007 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 *
 * =====================================================================================
 */

#include "kismetresponse.h"

kismetResponse::kismetResponse(QByteArray arr) : QByteArray(arr)
{
        lastRead        = -1;
        delimIx         = -1;
}

//Read specified (or next) field form Kismet response as QVariant
QVariant kismetResponse::read(bool *spd, int ix)
{
        QByteArray ret;
        if(ix == -1)
        {
                char delim      = 0x20;
                while(++delimIx < size() && at(delimIx) <= 0x20)
                        if(at(delimIx) == 1)
                        {
                                delim   = 1;
                                delimIx++;
                                break;
                        }

                //Report additional \001's
                if(spd)
                        *spd    = (delim == 1);

                if(delimIx == size())
                        return 0;

                int t   = indexOf(delim,delimIx);
                ret     = mid(delimIx, t-delimIx);
                delimIx = t;
        }

        return ret;
}
