/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 * 
 *       Filename:  kismodel.h
 * 
 *    Description:  qKismet generic data model
 * 
 *        Created:  2007-08-12 18:37:30 CEST
 * 
 *	Copyright (C) 2007 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 * 
 * =====================================================================================
 */

#ifndef  KISMODEL_INC
#define  KISMODEL_INC

#include "kisock.h"
#include <QAbstractItemModel>

class KismetItemModel : public QAbstractItemModel
{
public:
	virtual void clear() = 0;

	//register slot for stream of data like particular network's speed, etc.
	//ugly solution until all models will implememnt this
        virtual void RegisterDataStream(QString data, QObject* obj, const char* slot){Q_UNUSED(data);Q_UNUSED(obj);Q_UNUSED(slot);}
};

template<typename Root, typename Item>class KismetDataModel : public KismetItemModel
{
public:
        KismetDataModel()
	{
		rootItem	= new Root();
	}
	~KismetDataModel()
	{
		qDeleteAll(rootItem->items);
		delete rootItem;
	}
	
	int rowCount(const QModelIndex &parent = QModelIndex()) const
	{
		if(!parent.isValid())
			return rootItem->items.size();
		else return 0;
	}

	void clear()
	{
		beginRemoveRows(QModelIndex(),0,rowCount()-1);
		qDeleteAll(rootItem->items);
		rootItem->items.clear();
		endRemoveRows();
        }
protected:
	Root *rootItem;
};

#endif   /* ----- #ifndef KISMODEL_INC  ----- */

