/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 *
 *       Filename:  kisock.cpp
 *
 *    Description:  QKismetSocket, class communicating with Kismet server 
 *
 *        Created:  2007-07-05 16:14:10 CEST
 *
 *	Copyright (C) 2007 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 *
 * =====================================================================================
 */

#include "kisock.h"
#include "kismetresponse.h"
#include "protocolmanager.h"


#include <QStringList>
#include <QSettings>


QKismetSocket::QKismetSocket() 
{
	id = 0;
	connect(this,SIGNAL(stateChanged(QAbstractSocket::SocketState)),this,SIGNAL(stateCh(QAbstractSocket::SocketState)));
        prman   = new protocolManager(this);
}

QKismetSocket::~QKismetSocket()
{
        QSet<dataManager*> uniq;
        foreach(dataManager* m, protos.values())
                uniq |= m;
        foreach(dataManager* m, uniq)
                delete m;
}

void QKismetSocket::Connect(QString host,int port)
{
	connectToHost(host, port);
	connect(this,SIGNAL(readyRead()),this,SLOT(Read()));
}

void QKismetSocket::Disconnect()
{
	disconnectFromHost();
}

void QKismetSocket::Read()
{
	while(canReadLine())
	{
		QByteArray line = readLine();
		int sz	= line.size();
		if(line.endsWith("\n"))
		{
			sz--;
			if(line.endsWith("\r\n"))
				sz--;
			line.truncate(sz);
		}
                kismetResponse res      = line;
                QString head    = res.read().toString();

                //Head starts with '*' and ends with ':'
                QString proto   = head;
                proto.chop(1);
                proto.remove(0,1);
                if(protos.contains(proto))
                        protos[proto]->parseData(proto,res);

		if(line.startsWith("*TIME:"))
		{
			emit serverTime(line.mid(7).trimmed().toInt());
		}

                else if(head  == "*KISMET:")
                {
                        kismetInfo info(res);
                        newc = info.newcore();
			emit serverInfo(info);
                        emit socketReady();
		}
	}
}

void QKismetSocket::Pause()
{
	write("!");
	write(QByteArray::number(id++));
	write(" PAUSE\r\n");
}

void QKismetSocket::Resume()
{
	write("!");
	write(QByteArray::number(id++));
	write(" RESUME\r\n");
}

bool QKismetSocket::newcore()
{
        return newc;
}

void QKismetSocket::registerProtocol(dataManager *man, QString protocol)
{
        protos[protocol]        = man;
}

void QKismetSocket::sendCommand(QString cmd)
{
        write("!");
        write(QByteArray::number(id++));
        write(" ");
        write(cmd.toAscii());
        write("\r\n");
}

protocolManager* QKismetSocket::protoManager()
{
        return prman;
}

dataManager* QKismetSocket::managerForProtocol(const QString& protocol)
{
        if(protos.contains(protocol))
                return protos[protocol];
        else
                return 0;
}
