/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 *
 *       Filename:  kisock.h
 *
 *    Description:  QKismetSocket, class communicating with Kismet server
 *
 *        Created:  2007-07-05 16:14:10 CEST
 *
 *	Copyright (C) 2007 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 *
 * =====================================================================================
 */
#ifndef KISOCK_H
#define KISOCK_H


#include <QTcpSocket>
#include <QTextStream>
#include <QVariant>
#include <QHash>
#include <QStringList>
#include "settings.h"
#include "kismetinfo.h"
#include "datamanager.h"

class protocolManager;

class QKismetSocket : public QTcpSocket
{
	Q_OBJECT
public:
	QKismetSocket();
        ~QKismetSocket();



        bool newcore();
        void sendCommand(QString cmd);
        void registerProtocol(dataManager* man, QString protocol);
        protocolManager* protoManager();
        dataManager* managerForProtocol(const QString& protocol);

public slots:
	void Disconnect();
	void Connect(QString host=QKismetSettings::getInstance().Network.host, int port=QKismetSettings::getInstance().Network.port);
	void Pause();
	void Resume();
signals:
	void serverTime(int time);
	void serverInfo(kismetInfo info);
	void stateCh(QAbstractSocket::SocketState);
        void socketReady();
private:
        QHash<QString, dataManager*> protos;
        bool newc;
        int id;
        protocolManager *prman;
private slots:
	void Read();
};

#endif
