/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 *
 *       Filename:  kisview.h
 *
 *    Description:  QKismet generic view 
 *
 *        Created:  2007-07-05 16:14:10 CEST
 *
 *	Copyright (C) 2007 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 *
 * =====================================================================================
 */
#ifndef KISVIEW_H
#define KISVIEW_H

#include <QTreeWidget>
#include <QMenu>
#include "kismodel.h"
#include "kisfilter.h"
#include "settings.h"



class QKismetTreeView : public QTreeView
{
	Q_OBJECT

public:
	QKismetTreeView(QAbstractItemModel *model);
	~QKismetTreeView();
	QList<QAction*> menuActions();
	
	QList<QMenu*> menus;

	QMenu *popupMenu;
	QAction *aclear;
	KismetSortFilterProxy proxy;
	KismetItemModel* 	dataModel();

public slots:
	void showPopupMenu(const QPoint& pos);
	void cleared();
	void saveContents();
	void copyContents();
signals:
	void setOption(QString opt, bool enable);
private:
	void selectionChanged(const QItemSelection& selected, const QItemSelection& deselected);
	void rowsInserted(const QModelIndex& parent,int start, int end);
	void getIndexData(QModelIndex ix, bool selonly, QList<int>* cols, QString& out);
	void getIndexData(QModelIndex ix, bool selonly, QList<int>* cols, QTextStream& out);
	QAction *asave,*acopy,*asel;

	KismetItemModel *kmod;
};


#endif
