/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 *
 *       Filename:  netitem.cpp
 *
 *    Description:  Network view item 
 *
 *        Created:  2007-07-31 16:35:23 CEST
 *
 *	Copyright (C) 2007 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 *
 * =====================================================================================
 */

#include "netitem.h"

NetworkItem::NetworkItem(networkInfo *data, NetworkRootItem *parent) : networkInfo(*data)
{
        root    = parent;
}

NetworkItem::~NetworkItem()
{
	qDeleteAll(items);
	items.clear();
}

int NetworkItem::rowCount()
{
	return items.size();
}

QVariant NetworkItem::data(const networkOption& opt)
{
        return prettyPrint(opt);
}

int NetworkItem::row()
{
        return root->items.indexOf(this);
}

void* NetworkItem::parent()
{
        return root;
}

ClientItem* NetworkItem::addClient(clientInfo *info)
{
	ClientItem *r	= new ClientItem(info,this);
	items.append(r);
	return r;
}

ClientItem::ClientItem(clientInfo *data, NetworkItem *parent) : clientInfo(*data)
{
        par  = parent;
}

QVariant ClientItem::data(const networkOption &opt)
{
        clientOption op =  clientManager::analogicalOption(opt);
        if(op == ClientOptions::INVALID)
                return QVariant();
        else
                return prettyPrint(op);
}

int ClientItem::rowCount()
{
	return 0;
}

int ClientItem::row()
{
        return par->items.indexOf(this);
}

void * ClientItem::parent()
{
        return par;
}

