/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 * 
 *       Filename:  netitem.h
 * 
 *    Description:  Network model item
 * 
 *        Created:  2007-07-31 16:35:29 CEST
 * 
 *	Copyright (C) 2007 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 *
 * =====================================================================================
 */

#ifndef  NETITEM_INC
#define  NETITEM_INC

#include <QList>
#include <QVariant>
#include <QColor>
#include <QPair>
#include <QHash>

#include "networkinfo.h"
#include "clientinfo.h"

struct NetworkRootItem;
class ClientItem;

class NetmodelItem
{
public:
        virtual ~NetmodelItem(){}
	virtual int	row()			= 0;
	virtual void*	parent()		= 0;
	virtual int	rowCount()		= 0;
        virtual QVariant data(const networkOption &opt)	= 0;
	
	QColor 	color;
	bool 	hasColor;
};

class NetworkItem : public networkInfo, public NetmodelItem
{
public:
	NetworkItem(networkInfo *data,NetworkRootItem *parent);
	~NetworkItem();

	int rowCount();
        int row();
        void* parent();

        ClientItem*	addClient(clientInfo *info);
        QVariant data(const networkOption &opt);

	QList<ClientItem*> items;
private:
        NetworkRootItem *root;
};

struct NetworkRootItem
{
	public:
		QList<NetworkItem*> items;
};

class ClientItem : public clientInfo, public NetmodelItem
{
public:
        ClientItem(clientInfo *data, NetworkItem *parent);
	int rowCount();
        int row();
        void* parent();

        QVariant data(const networkOption &opt);
private:
        NetworkItem *par;
};
#endif   /* ----- #ifndef NETITEM_INC  ----- */

