/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 * 
 *       Filename:  netmodel.h
 * 
 *    Description:  Network view data model
 * 
 *        Created:  2007-07-31 16:13:39 CEST
 * 
 *	Copyright (C) 2007 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 * 
 * =====================================================================================
 */

#ifndef  NETMODEL_INC
#define  NETMODEL_INC

#include <QAbstractItemModel>
#include <QMimeData>

#include "netitem.h"
#include "networkinfo.h"
#include "kismodel.h"


class NetworkModel : public KismetDataModel<NetworkRootItem, NetworkItem>
{
	Q_OBJECT
public:
                NetworkModel(networkManager *man, clientManager *cman);

		Qt::ItemFlags flags( const QModelIndex &index ) const;
		QVariant data(const QModelIndex &index, int role) const;
		QVariant headerData(int section, Qt::Orientation orientation,int role = Qt::DisplayRole) const;

		QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const;
		QModelIndex parent(const QModelIndex &index) const;
		int columnCount(const QModelIndex &parent = QModelIndex()) const;
		int rowCount(const QModelIndex &parent = QModelIndex()) const;


                const QHash<int,networkOption>& columnOptions();
signals:
		void itemDataRate(QString mac, int dataRate);

public slots:
		void netInfo(networkInfo info);
                void cliInfo(clientInfo info);
private:
		NetworkItem	*findItem(QString &bssid);
                QHash<int,networkOption> columnToOption;

                int colCount;
                networkManager *manager;
                clientManager *cmanager;
private slots:
                void updateColumns();
                void updateClientOptions(networkOption option, bool enable);

};

#endif   /* ----- #ifndef NETMODEL_INC  ----- */

