/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 *
 *       Filename:  netview.cpp
 *
 *    Description:  Network view
 *
 *        Created:  2007-07-05 16:14:10 CEST
 *
 *	Copyright (C) 2007 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 *
 * =====================================================================================
 */
#include "netview.h"
#include "headmenu.h"
#include "clientinfo.h"

#include <QHeaderView>
#include <QApplication>
#include <QSettings>

QKismetNetView::QKismetNetView(QKismetSocket *sock) : QKismetTreeView(new NetworkModel((netMan = networkManager::manager(sock)),(cliMan = clientManager::manager(sock))))
{
	socket = sock;

        setUniformRowHeights(true);

        cliMan->setOption((clientOption)ClientOptions::Bssid);
        cliMan->setOption((clientOption)ClientOptions::Mac);
        netMan->setOption((networkOption)NetworkOptions::Bssid);

        connect(netMan,SIGNAL(activeChanged()),this,SLOT(updateColumnVisibility()));
        connect(netMan,SIGNAL(capabilitiesChanged()),this,SLOT(updateColumnVisibility()));

        //Read saved settings.
        //Need some fixes to be fully working
        QSettings set("qkismet","qkismet");
        set.beginGroup("NetworkViewSettings");
        QList<QVariant> options,sizes;


        options = set.value("Options",QList<QVariant>() << NetworkOptions::Bssid << NetworkOptions::Ssid << NetworkOptions::Type).toList();
        sizes = set.value("ColumnSizes").toList();

        foreach(QVariant v,options)
                netMan->setOption(v.toInt());

        QHeaderView *head       = header();

        for(int i = 0; i < sizes.size(); i++)
                head->resizeSection(i,sizes[i].toInt());

        setDragEnabled(true);

        createMenus();

        updateColumnVisibility();

}
QKismetNetView::~QKismetNetView()
{
	SaveSettings();
        delete headMenu;
}
void QKismetNetView::createMenus()
{
        headMenu	= new HeadMenu(netMan,this);
	
	QHeaderView *head = header();
	head->setContextMenuPolicy(Qt::CustomContextMenu);
        
        connect(head,SIGNAL(customContextMenuRequested(const QPoint&)),headMenu,SLOT(show(const QPoint&)));
}
void QKismetNetView::SaveSettings()
{
        QSettings set("qkismet","qkismet");
        set.beginGroup("NetworkViewSettings");

        QList<QVariant> sizes;

        foreach(networkOption o,netMan->enabledOptions())
                sizes << (int)o;

        set.setValue("Options",sizes);
        
        sizes.clear();
        
        QHeaderView *head       = header();
        for(int i = 0; i < head->count(); i++)
                sizes << head->sectionSize(i);

        set.setValue("ColumnSizes",sizes);
}

void QKismetNetView::updateColumnVisibility()
{
        NetworkModel *mod       = (NetworkModel*)dataModel();

        QSet<networkOption> enabled    = netMan->enabledOptions();
        QSet<protocolOption> avail       = netMan->availableOptions();

        foreach(protocolOption opt,avail)
        {
                int id  = mod->columnOptions().key(opt,0);

                if(enabled.contains(opt))
                        showColumn(id);
                else
                        hideColumn(id);
        }
}
