/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 *
 *       Filename:  protocolmanager.cpp
 *
 *    Description:  Manages informations about protocols from the server
 *
 *        Created:  2009-09-10 12:19:38 CEST
 *
 *	Copyright (C) 2009 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 *
 * =====================================================================================
 */

#include "protocolmanager.h"

protocolManager::protocolManager(QKismetSocket *socket)
{
        connect(socket,SIGNAL(socketReady()),this,SLOT(socketReady()));
        socket->registerProtocol(this,"PROTOCOLS");
        socket->registerProtocol(this,"CAPABILITY");

        sock    = socket;
}

void protocolManager::socketReady()
{

}

void protocolManager::parseData(const QString &protocol, kismetResponse &response)
{
        if(protocol == "PROTOCOLS")
        {
                protos  = response.read().toString().split(",");
                foreach(QString p,protos)
                        sock->sendCommand("CAPABILITY "+p);
        }
        else
        {
                QString prot    = response.read().toString();
                cap[prot]  = response.read().toString().split(",");
                emit capsChanged(prot);
        }
}

const QStringList& protocolManager::protocols()
{
        return protos;
}

const QStringList& protocolManager::caps(const QString& protocol)
{
        return cap[protocol];
}
