/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 *
 *       Filename:  statmodel.cpp
 *
 *    Description:  Status messages model
 *
 *        Created:  2007-08-10 18:42:51 CEST
 *
 *	Copyright (C) 2007 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 *
 * =====================================================================================
 */

#include "statmodel.h"
#include <QIcon>

StatusModel::StatusModel(statusManager *man) : KismetDataModel<StatusRootItem,StatusItem>()
{
        manager = man;
        connect(man,SIGNAL(data(statusInfo)),this,SLOT(statInfo(statusInfo)));
}

QVariant StatusModel::data(const QModelIndex &index, int role) const
{
	if(!index.isValid())
		return QVariant();

        if(role == Qt::DecorationRole && index.column() == 0)
        {
                StatusItem *item	= static_cast<StatusItem*>(index.internalPointer());
                if(item->flags & statusFlags::Info)
                        return QIcon(":/img/info.png");
                else if(item->flags & statusFlags::Error)
                        return QIcon(":/img/error.png");
                else if(item->flags & statusFlags::Fatal)
                        return QIcon(":/img/fatal.png");
                return QVariant();
        }
        if(role == Qt::DisplayRole)
        {
                StatusItem *item	= static_cast<StatusItem*>(index.internalPointer());
                return item->data(index.column());
        }
        return QVariant();
}

QVariant StatusModel::headerData(int section, Qt::Orientation orientation,int role) const
{
	if(orientation == Qt::Horizontal && role == Qt::DisplayRole)
		switch(section)
		{
			case 0: return "Time";
			case 1: return "Text";
			default: return QVariant();
		}
	return QVariant();
}

QModelIndex StatusModel::index(int row, int column, const QModelIndex &parent) const
{
	if(!hasIndex(row,column,parent))
		return QModelIndex();
		
	StatusItem *it	= rootItem->items[row];
	if(it)
		return createIndex(row,column,it);
	else
		return QModelIndex();
}

QModelIndex StatusModel::parent(const QModelIndex &index) const
{
	if(index.isValid())
		return QModelIndex();
	
	return QModelIndex();
}

int StatusModel::columnCount(const QModelIndex&) const
{
        return 2;
}

void StatusModel::statInfo(statusInfo info)
{
	int c	= rootItem->items.size();
	
	beginInsertRows(QModelIndex(),c,c);
	
        StatusItem *item	= new StatusItem(info,rootItem);
	rootItem->items.append(item);
	
	endInsertRows();
}

//StatusItem implementation

StatusItem::StatusItem(statusInfo &info, StatusRootItem *parent) : statusInfo(info)
{
	root	= parent;
}

QVariant StatusItem::data(int column)
{
	if(column == 0)
		return time.toString();
	else if(column == 1)
                return text;
	else return QVariant();
}

StatusRootItem* StatusItem::parent()
{
	return root;
}

int StatusItem::row()
{
	return root->items.indexOf(this);
}
