/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 *
 *       Filename:  statusinfo.cpp
 *
 *    Description:  status informations
 *
 *        Created:  2009-09-19 16:53:42 CEST
 *
 *	Copyright (C) 2009 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 *
 * =====================================================================================
 */

#include "statusinfo.h"

statusInfo::statusInfo(kismetResponse &response, bool hasFlags)
{
        time	= QDateTime::currentDateTime();

        if(hasFlags)
        {
                text    = response.read().toString();
                flags   = response.read().toInt();
        }
        else
        {
                //No flags = we are connected to old kismet = we have only one fields,
                //so there are no delimiters.
                text    = response.mid(9);
                flags   = 0;
        }
}

statusManager::statusManager(QKismetSocket *socket)
{
        sock    = socket;
        capabilitiesChanged("STATUS");
        connect(sock->protoManager(),SIGNAL(capsChanged(QString)),this,SLOT(capabilitiesChanged(QString)));
        sock->registerProtocol(this,"STATUS");
}

statusManager* statusManager::manager(QKismetSocket *socket)
{
        statusManager *ret        = (statusManager*)socket->managerForProtocol("STATUS");

        return (ret) ? ret : new statusManager(socket);
}

void statusManager::parseData(const QString&, kismetResponse &response)
{
        qDebug() << response;
        emit data(statusInfo(response,flagsEnabled));
}

void statusManager::update()
{
        if(!sock->isWritable())
                return;

        QString cmd     = "ENABLE STATUS text";
        if(flagsEnabled)
                cmd     += ",flags";

        qDebug () << cmd;
        sock->sendCommand(cmd);
}

void statusManager::socketReady()
{
        update();
}

void statusManager::capabilitiesChanged(const QString& protocol)
{
        if(protocol == "STATUS")
        {
                flagsEnabled    = sock->protoManager()->caps("STATUS").contains("flags");
                update();
        }
}
