/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 *
 *       Filename:  statusinfo.h
 *
 *    Description:  Status informations
 *
 *        Created:  2009-09-19 16:53:42 CEST
 *
 *	Copyright (C) 2009 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 *
 * =====================================================================================
 */
#ifndef STATUSINFO_H
#define STATUSINFO_H

#include <QString>
#include <QDateTime>
#include "kismetresponse.h"
#include "protocolmanager.h"

class QKismetSocket;

namespace statusFlags
{
        enum e
        {
                None    = 0,
                Debug   = 1,
                Info    = 2,
                Error   = 4,
                Alert   = 8,
                Fatal   = 16
        };
}

class statusInfo
{
public:
        statusInfo(kismetResponse &response, bool hasFlags);

        QString text;
        unsigned int flags;
        QDateTime time;
};

//This class is much simpler than classes responsible for information about networks and clients
//STATUS protocol has one (text) or two (text, flags) options. All possible options are always enabled
class statusManager : public dataManager
{
        Q_OBJECT
public:
        static statusManager* manager(QKismetSocket *socket);

        void parseData(const QString &protocol, kismetResponse &response);

signals:
        void data(statusInfo info);

private:
        statusManager(QKismetSocket *socket);
        bool flagsEnabled;
        void update();

        QKismetSocket *sock;

private slots:
        void socketReady();
        //Called when info about supported protocol fields received
        void capabilitiesChanged(const QString& protocol);
};

#endif // STATUSINFO_H
