/*
 * =====================================================================================
 *
 *	This file is part of qKismet, Qt Kismet GUI.
 *
 *	qKismet is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	qKismet is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =====================================================================================
 *
 *       Filename:  statview.cpp
 *
 *    Description:  Status messages view
 *
 *        Created:  2007-07-05 16:14:10 CEST
 *
 *	Copyright (C) 2007 Krzysztof Tyszecki <krzychoocpp@gmail.com>
 *
 * =====================================================================================
 */
#include "statview.h"
#include <QHeaderView>


QKismetStatusWnd::QKismetStatusWnd(QKismetSocket *sock)
{
	view	= new QKismetStatusView(sock);
	toolbar	= new QKismetViewToolBar(view);

	view->popupMenu->addSeparator();
	view->popupMenu->addAction(toolbar->toggleViewAction());
	
	setCentralWidget(view);
	addToolBar(toolbar);
}
QKismetStatusWnd::~QKismetStatusWnd()
{
	delete view;
	delete toolbar;
}

QKismetStatusDock::QKismetStatusDock(QKismetSocket *sock)
{
	hide();
	
	tree	= new QKismetStatusWnd(sock);

	QAction *a = toggleViewAction();
	a->setIcon(QIcon(":/img/text-x-generic.png"));
	a->setStatusTip("Toggle status messages window");
	setWindowTitle("Status messages");



	setWidget(tree);
}
QKismetStatusDock::~QKismetStatusDock()
{
	delete tree;
}

QKismetStatusView::QKismetStatusView(QKismetSocket *sock) : QKismetTreeView(new StatusModel((statusManager::manager(sock))))
{
	connect(aclear,SIGNAL(triggered()),model(),SLOT(clear()));
	setRootIsDecorated(false);

#if QT_VERSION >= 0x040200
	header()->setResizeMode(QHeaderView::ResizeToContents);
	header()->hide();
#endif
	setAutoScroll(true);
	setSelectionMode(QAbstractItemView::ExtendedSelection);
}
